@@ -1,11 +1,11 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# $Revision: 1.39 $ 
-# $Date: 2005/01/11 19:00:58 $
+# $Revision: 1.46 $ 
+# $Date: 2005/03/23 23:54:06 $
 # $Author: dwelch $
 #
-# (c) Copyright 2001-2004 Hewlett-Packard Development Company, L.P.
+# (c) Copyright 2001-2005 Hewlett-Packard Development Company, L.P.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -23,46 +23,52 @@
 #
 # Author: Don Welch
 #
-
-
-
+# Thanks to Henrique M. Holschuh <hmh@debian.org> for various security patches
+#
 
 from __future__ import generators 
 
-#try:
-#    import warnings
-#    warnings.simplefilter( 'ignore', FutureWarning )
-#except:
-#    pass
-
-
 # Std Lib
 import sys, os
 import fnmatch
 import tempfile
 import socket
 import msg
-import os
 import struct
 import select
 import time
 import traceback
 import fcntl
-import errno    
-
+import errno
+import stat
+import string
 
 # Local
 from g import *
 from codes import *
-import device
-#import logger
+
+
+def Translator(frm='', to='', delete='', keep=None):
+    allchars = string.maketrans('','')
+    
+    if len(to) == 1:
+        to = to * len(frm)
+    trans = string.maketrans(frm, to)
+    
+    if keep is not None:
+        delete = allchars.translate(allchars, keep.translate(allchars, delete))
+    
+    def callable(s):
+        return s.translate(trans, delete)
+    
+    return callable
 
 # For pidfile locking (must be "static" and global to the whole app)
 prv_pidfile = None
 prv_pidfile_name = ""
 
 
-def get_pidfile_lock ( a_pidfile_name ):
+def get_pidfile_lock ( a_pidfile_name="" ):
     """ Call this to either lock the pidfile, or to update it after a fork()
         Credit: Henrique M. Holschuh <hmh@debian.org> 
     """
@@ -108,13 +114,13 @@ def daemonize ( stdin='/dev/null', stdout='/dev/null', stderr='/dev/null' ):
     """
     Credit: Jürgen Hermann, Andy Gimblett, and Noah Spurrier
             http://aspn.activestate.com/ASPN/Cookbook/Python/Recipe/66012
-    
+
     Proper pidfile support: Henrique M. Holschuh <hmh@debian.org>
     """
     # Try to lock pidfile if not locked already
     if prv_pidfile_name != '' or prv_pidfile_name != "":
         get_pidfile_lock( prv_pidfile_name )    
-    
+
     # Do first fork.
     try: 
         pid = os.fork() 
@@ -123,12 +129,12 @@ def daemonize ( stdin='/dev/null', stdout='/dev/null', stderr='/dev/null' ):
     except OSError, e: 
         sys.stderr.write ("fork #1 failed: (%d) %s\n" % (e.errno, e.strerror)    )
         sys.exit(1)
-    
+
     # Decouple from parent environment.
     os.chdir("/") 
     os.umask(0) 
     os.setsid() 
-    
+
     # Do second fork.
     try: 
         pid = os.fork() 
@@ -137,12 +143,12 @@ def daemonize ( stdin='/dev/null', stdout='/dev/null', stderr='/dev/null' ):
     except OSError, e: 
         sys.stderr.write ("fork #2 failed: (%d) %s\n" % (e.errno, e.strerror)    )
         sys.exit(1)
-    
+
     if prv_pidfile_name != "":
-        get_pidfile_lock("")
+        get_pidfile_lock()
 
     # Now I am a daemon!
-    
+
     # Redirect standard file descriptors.
     si = file(stdin, 'r')
     so = file(stdout, 'a+')
@@ -150,7 +156,7 @@ def daemonize ( stdin='/dev/null', stdout='/dev/null', stderr='/dev/null' ):
     os.dup2(si.fileno(), sys.stdin.fileno())
     os.dup2(so.fileno(), sys.stdout.fileno())
     os.dup2(se.fileno(), sys.stderr.fileno())
-    
+
 
 
 def ifelse( cond, t, f ):
@@ -166,7 +172,7 @@ def to_bool_str( s, default='0' ):
             return '0'
 
     return default
-    
+
 def to_bool( s, default=False ):
     """ Convert an arbitrary 0/1/T/F/Y/N string to a boolean True/False value.""" 
     if len( s ):
@@ -177,25 +183,33 @@ def to_bool( s, default=False ):
 
     return default
 
-        
+def path_exists_safely( path ):
+    """ Returns True if path exists, and points to a file with permissions at least as strict as 0755.
+        Credit: Contributed by Henrique M. Holschuh <hmh@debian.org>"""
+    try:
+        pathmode = os.stat( path )[stat.ST_MODE]
+        if pathmode & 0022 != 0:
+            return False
+    except (IOError,OSError):
+        return False
+    return True
+
+
 def walkFiles( root, recurse=True, abs_paths=False, return_folders=False, pattern='*', path=None ):
-    
-    #import string
-    
     if path is None:
         path = root
-    
+
     try:
         names = os.listdir( root )
     except os.error:
         raise StopIteration
-    
+
     pattern = pattern or '*'
     pat_list = pattern.split( ';' )
-    
+
     for name in names:
         fullname = os.path.normpath( os.path.join( root, name ) )
-        
+
         for pat in pat_list:
             if fnmatch.fnmatch( name, pat ):
                 if return_folders or not os.path.isdir( fullname ):
@@ -206,32 +220,44 @@ def walkFiles( root, recurse=True, abs_paths=False, return_folders=False, patter
                             yield fullname[ fullname.find( path ) + len( path ) : ]
                         except ValueError:
                             yield fullname
-                        
+
         if os.path.islink( fullname ):
             fullname = os.path.realpath( os.readlink( fullname ) )
-        
+
         if recurse and os.path.isdir( fullname ) or os.path.islink( fullname ):
             for f in walkFiles( fullname, recurse, abs_paths, return_folders, pattern, path ):
                 yield f
-                        
 
 
+def is_path_writable( path ):
+    
+    if os.path.exists( path ):
+        s = os.stat( path )
+        mode = s[ stat.ST_MODE ] & 0777
+        
+        if mode & 02:
+            return True
+        elif s[ stat.ST_GID ] == os.getgid() and mode & 020:
+            return True
+        elif s[ stat.ST_UID ] == os.getuid() and mode & 0200:
+            return True
+    
+    return False
+    
 
 # Provides the TextFormatter class for formatting text into columns.
 # Original Author: Hamish B Lawson, 1999
 # Modified by: Don Welch, 2003
 class TextFormatter:
-    
+
     LEFT  = 0
     CENTER = 1
     RIGHT  = 2
-    
+
     def __init__( self, colspeclist ):
         self.columns = []
         for colspec in colspeclist:
             self.columns.append( Column( **colspec ) ) 
-        
-
 
     def compose(self, textlist, add_newline=False):
         numlines = 0
@@ -250,13 +276,13 @@ class TextFormatter:
             return '\n'.join(complines) + '\n'
         else:
             return '\n'.join(complines)
-            
+
     def bold( text ):
         return ''.join( [ "\033[1m", text, "\033[0m" ] )
-        
+
     bold = staticmethod( bold )
 
-            
+
 class Column:
 
     def __init__(self, width=78, alignment=TextFormatter.LEFT, margin=0):
@@ -299,45 +325,46 @@ class Column:
         else:
             return ' ' * (self.margin + self.width)
 
-            
 
-def getInteractiveDeviceURI( bus='cups', filter='none' ): 
+
+def getInteractiveDeviceURI( bus='cups,usb', filter='none' ): 
     from prnt import cups
     bus = bus.lower()
-    
+
     log.warn( "Device not specified.")
 
-    if bus == 'cups':
-        log.info(  bold( "\nChoose device from CUPS installed devices:" ) )
-        cups_devices = {}
-        cups_printers = cups.getPrinters()
-        x = len( cups_printers )
-        max_deviceid_size = 0
-        
-        for p in cups_printers:
-            device_uri = p.device_uri
-            if p.device_uri == '':
-                device_uri = '?UNKNOWN?'
-            
-            try:
-                cups_devices[ device_uri ]
-            except KeyError: 
-                cups_devices[ device_uri ] = ( device_uri, [ p.name ] )
-            else:
-                cups_devices[ device_uri ][1].append( p.name )
-            
-            max_deviceid_size = max( len( p.device_uri ), max_deviceid_size ) 
-            
-        devices, x = {}, 0
-        for y in cups_devices:
-            devices[x] = cups_devices[y]
-            x += 1
-    
-    else:   
-        log.info(  bold( "\nChoose device from probed devices connected on bus '%s':\n" % bus ) ) 
+##    if bus == 'cups':
+##        log.info(  bold( "\nChoose device:" ) )
+##        cups_devices = {}
+##        cups_printers = cups.getPrinters()
+##        x = len( cups_printers )
+##        max_deviceid_size = 0
+##
+##        for p in cups_printers:
+##            device_uri = p.device_uri
+##            if p.device_uri == '':
+##                device_uri = '?UNKNOWN?'
+##
+##            try:
+##                cups_devices[ device_uri ]
+##            except KeyError: 
+##                cups_devices[ device_uri ] = ( device_uri, [ p.name ] )
+##            else:
+##                cups_devices[ device_uri ][1].append( p.name )
+##
+##            max_deviceid_size = max( len( p.device_uri ), max_deviceid_size ) 
+##
+##        devices, x = {}, 0
+##        for y in cups_devices:
+##            devices[x] = cups_devices[y]
+##            x += 1
+
+    #else:   
+    if 1:
+        log.info(  bold( "\nChoose device from probed devices connected on bus(es) %s:\n" % bus ) ) 
         hpssd_sock = socket.socket( socket.AF_INET, socket.SOCK_STREAM )
         hpssd_sock.connect( ( prop.hpssd_host, prop.hpssd_port ) )
-        
+
         fields, data = msg.xmitMessage( hpssd_sock, 
                                         "ProbeDevicesFiltered",
                                         None, 
@@ -347,7 +374,7 @@ def getInteractiveDeviceURI( bus='cups', filter='none' ):
                                             'ttl' : 4,
                                             'format' : 'default',
                                             'filter' : filter,
-                                                
+
                                         } 
                                       )
         hpssd_sock.close()  
@@ -359,7 +386,7 @@ def getInteractiveDeviceURI( bus='cups', filter='none' ):
         log.debug( probed_devices )
         log.debug( cups_printers )
         max_deviceid_size, x, devices = 0, 0, {} 
-        
+
         for d in probed_devices:
             printers = []
             for p in cups_printers:
@@ -368,7 +395,7 @@ def getInteractiveDeviceURI( bus='cups', filter='none' ):
             devices[x] = ( d, printers )
             x += 1
             max_deviceid_size = max( len(d), max_deviceid_size )
-    
+
     if x == 0:
         log.error( "No devices found." )
         raise Error( ERROR_NO_PROBED_DEVICES_FOUND )
@@ -376,7 +403,7 @@ def getInteractiveDeviceURI( bus='cups', filter='none' ):
         log.info( "Using device: %s" % devices[0][0] )
         return devices[0][0]
     else:    
-        
+
         formatter = TextFormatter( 
                 (
                     {'width': 4},
@@ -388,11 +415,11 @@ def getInteractiveDeviceURI( bus='cups', filter='none' ):
         log.info( formatter.compose( ( '-'*4, '-'*(max_deviceid_size), '-'*( 80-max_deviceid_size-10 ) ) ) )
         for y in range( x ):
             log.info(  formatter.compose( ( str(y), devices[y][0], ', '.join( devices[y][1] ) ) ) )
-        
+
         while 1:
             user_input = raw_input( bold( "\nEnter number 0...%d for device (q=quit) ?" % (x-1) ) )
             if user_input == '': 
-                log.warn( "Invalid input - enter a numeric value or 'q' ro quit." )
+                log.warn( "Invalid input - enter a numeric value or 'q' to quit." )
                 continue
             if user_input.strip()[0] in ( 'q', 'Q' ):
                 return
@@ -405,56 +432,32 @@ def getInteractiveDeviceURI( bus='cups', filter='none' ):
                 log.warn( "Invalid input - enter a value between 0 and %d or 'q' to quit." % (x-1) )
                 continue
             break
-        
+
         return devices[i][0]
 
-        
+
 
 class Stack:
     def __init__( self ):
         self.stack = []
-        
+
     def pop( self ):
         return self.stack.pop()
-        
+
     def push( self, value ):
         self.stack.append( value )
-        
+
     def as_list( self ):
         return self.stack
-        
+
     def clear( self ):
         self.stack = []
-        
+
 
 # RingBuffer class       
 # Source: Python Cookbook 1st Ed., sec. 5.18, pg. 201
 # Credit: Sebastien Keim
 # License: Modified BSD
-        
-if 0:
-    class RingBuffer:
-        def __init__( self, size_max=50 ):
-            self.max = size_max
-            self.data = []
-            
-        class __Full:
-            def append( self, x ):
-                self.data[ self.cur ] = x
-                self.cur = ( self.cur+1 ) % self.max
-                
-            def get(self ):
-                return self.data[ self.cur: ] + self.data[ :self.cur ]
-                
-        def append( self, x ):
-            self.data.append( x )
-            if len( self.data ) == self.max:
-                self.cur = 0
-                self.__class__ = RingBuffer.__Full
-                
-        def get( self ):
-            return self.data
-        
 class RingBuffer:
     def __init__(self,size_max=50):
         self.max = size_max
@@ -472,13 +475,14 @@ class RingBuffer:
 
 class RingBufferFull:
     def __init__(self,n):
-        raise "you should use RingBuffer"
+        #raise "you should use RingBuffer"
+        pass
     def append(self,x):     
         self.data[self.cur]=x
         self.cur=(self.cur+1) % self.max
     def get(self):
         return self.data[self.cur:]+self.data[:self.cur]
-        
+
 
 # CRC routines for RP
 if 0:
@@ -490,11 +494,11 @@ if 0:
             else:
                 crc = crc >> 1
             ch = ch >> 1
-        
+
         return crc
-    
-    
-    
+
+
+
 # 16-bit CRCs should detect 65535/65536 or 99.998% of all errors in
 # data blocks up to 4096 bytes
 MASK_CCITT  = 0x1021     # CRC-CCITT mask (ISO 3309, used in X25, HDLC)
@@ -523,17 +527,17 @@ def calcCRC( data ):
     crc = 0
     #for c in data:
     #    crc = updateCRC( crc, c )
-    
+
     crc = updateCRC( crc, data )
-    
+
     if crc == 0:
         crc = len( data )
-    
+
     return crc
-    
-    
-    
-    
+
+
+
+
 def sort_dict_by_value(d):
     """ Returns the keys of dictionary d sorted by their values """
     items=d.items()
@@ -622,7 +626,7 @@ def commafy(val):
     return val < 0 and '-' + commafy( abs( val ) ) \
         or val < 1000 and str( val ) \
         or '%s,%03d' % ( commafy( val / 1000 ), (val % 1000) )
-   
+
 
 def format_bytes( s, show_bytes=False ):
     if s < 1024:
@@ -637,7 +641,7 @@ def format_bytes( s, show_bytes=False ):
             return ''.join( [ str( round( s/1048576.0, 1 ) ), ' MB (',  commafy(s), ')' ] )
         else:
             return ''.join( [ str( round( s/1048576.0, 1 ) ), ' MB' ] )
-    
+
 
 
 try:
@@ -651,15 +655,17 @@ except AttributeError:
         return ( fd, path )
 
 def log_title( program_name, version ):
-    log.info( "HP Linux Imaging and Printing System (ver. %s)" % prop.version )
-    log.info( "%s ver. %s" % ( program_name,version) )
-    log.info( "Copyright (c) 2003-4 Hewlett-Packard Development Company, LP" )
+    log.info( "" )
+    log.info( bold( "HP Linux Imaging and Printing System (ver. %s)" % prop.version ) )
+    log.info( bold( "%s ver. %s" % ( program_name,version) ) )
+    log.info( "" ) 
+    log.info( "Copyright (c) 2003-5 Hewlett-Packard Development Company, LP" )
     log.info( "This software comes with ABSOLUTELY NO WARRANTY." )
     log.info( "This is free software, and you are welcome to distribute it" )
     log.info( "under certain conditions. See COPYING file for more details." )
     log.info( "" )
-    
-    
+
+
 def which( command ):
     path = os.getenv( 'PATH' ).split( ':' )
     found_path = ''
@@ -672,47 +678,55 @@ def which( command ):
             if command in files:
                 found_path = p
                 break
-            
+
     return found_path
-    
-    
+
+
 def deviceDefaultFunctions():
+    cmd_print, cmd_copy, cmd_fax, cmd_pcard, cmd_scan = \
+        '', '', '', '', ''
+    
     # Print
     path = which( 'kprinter' )
+    
     if len(path) > 0:
         cmd_print = 'kprinter -P%PRINTER% --system cups'
     else:
         path = which( 'gtklp' )
-    
+
         if len(path) > 0:
             cmd_print = 'gtklp -P%PRINTER%'
-        else:
-            cmd_print = ''
         
+        else:
+            path = which( 'xpp' )
+             
+            if len( path ) > 0:
+                cmd_print = 'xpp -P%PRINTER%'
+            
+
     # Scan
     path = which( 'xsane' )
+
     if len(path) > 0:
         cmd_scan = 'xsane -V %SANE_URI%'
-    else:
-        cmd_scan = ''
-        
+
     # Photo Card
     files = os.listdir( prop.home_dir )
+    
     if 'unload' in files:
         cmd_pcard = 'python %HOME%/unload -d %DEVICE_URI%'
+    
     elif 'unload.py' in files:
         cmd_pcard = 'python %HOME%/unload.py -d %DEVICE_URI%'
-    else:
-        cmd_pcard = ''
-        
+
     # Copy
-    cmd_copy = ''
-    
+    #
+
     # Fax
-    cmd_fax = ''
-    
-    return ( cmd_print, cmd_scan, cmd_pcard, cmd_copy, cmd_fax )
-    
+    #
+
+    return cmd_print, cmd_scan, cmd_pcard, cmd_copy, cmd_fax
+
 
 
 
@@ -750,142 +764,131 @@ def deviceDefaultFunctions():
 # unsigned. My thanks to Jerome Poincheval for the fix.
 #
 
-
 # From /usr/include/linux/icmp.h; your milage may vary.
-ICMP_ECHO_REQUEST=8 # Seems to be the same on Solaris.
+ICMP_ECHO_REQUEST = 8 # Seems to be the same on Solaris.
 
 # I'm not too confident that this is right but testing seems
 # to suggest that it gives the same answers as in_cksum in ping.c
-def checksum(str):
-  sum=0
-  countTo=(len(str)/2)*2
-  count=0
-  while count<countTo:
-    thisVal=ord(str[count+1])*256+ord(str[count])
-    sum=sum+thisVal
-    sum=sum & 0xffffffffL # Necessary?
-    count=count+2
+def checksum( str ):
+  csum = 0
+  countTo = ( len(str) / 2 ) * 2
+  count = 0
+  while count < countTo:
+    thisVal = ord( str[count+1] ) * 256 + ord( str[count] )
+    csum = csum + thisVal
+    csum = csum & 0xffffffffL # Necessary?
+    count = count + 2
 
-  if countTo<len(str):
-    sum=sum+ord(str[len(str)-1])
-    sum=sum & 0xffffffffL # Necessary?
+  if countTo < len(str):
+    csum = csum + ord( str[ len(str) - 1 ] )
+    csum = csum & 0xffffffffL # Necessary?
 
-  sum=(sum >> 16) + (sum & 0xffff)
-  sum=sum+(sum >> 16)
-  answer=~sum
-  answer=answer & 0xffff
+  csum = ( csum >> 16 ) + ( csum & 0xffff )
+  csum = csum + ( csum >> 16 )
+  answer = ~csum
+  answer = answer & 0xffff
 
   # Swap bytes. Bugger me if I know why.
-  answer=answer >> 8 | (answer << 8 & 0xff00)
-  
+  answer = answer >> 8 | (answer << 8 & 0xff00)
+
   return answer
 
-def receiveOnePing(mySocket,ID,timeout):
-  timeLeft=timeout
+def receiveOnePing(mySocket, ID, timeout ):
+  timeLeft = timeout
+
   while 1:
-    startedSelect=time.time()
-    whatReady=select.select([mySocket],[],[],timeLeft)
-    howLongInSelect=(time.time()-startedSelect)
-    if whatReady[0]==[]: # Timeout
-      return -1
-    timeReceived=time.time()
-    recPacket,addr=mySocket.recvfrom(1024)
-    icmpHeader=recPacket[20:28]
-    type,code,checksum,packetID,sequence=struct.unpack("bbHHh",icmpHeader)
-    if packetID==ID:
-      bytesInDouble=struct.calcsize("d")
-      timeSent=struct.unpack("d",recPacket[28:28+bytesInDouble])[0]
-      return timeReceived-timeSent
-      
-    timeLeft=timeLeft-howLongInSelect
-    if timeLeft<=0:
+    startedSelect = time.time()
+    whatReady = select.select( [mySocket], [], [], timeLeft )
+    howLongInSelect = ( time.time() - startedSelect )
+
+    if whatReady[0] == []: # Timeout
       return -1
 
-def sendOnePing(mySocket,destAddr,ID):
+    timeReceived = time.time()
+    recPacket, addr = mySocket.recvfrom(1024)
+    icmpHeader = recPacket[20:28]
+    typ, code, checksum, packetID, sequence = struct.unpack( "bbHHh", icmpHeader )
+
+    if packetID == ID:
+      bytesInDouble = struct.calcsize( "d" )
+      timeSent = struct.unpack( "d", recPacket[ 28:28 + bytesInDouble ] )[0]
+      return timeReceived - timeSent
+
+    timeLeft = timeLeft - howLongInSelect
+
+    if timeLeft <= 0:
+      return -1
+
+def sendOnePing( mySocket, destAddr, ID ):
   # Header is type (8), code (8), checksum (16), id (16), sequence (16)
-  myChecksum=0
+  myChecksum = 0
+  
   # Make a dummy heder with a 0 checksum.
-  header=struct.pack("bbHHh",ICMP_ECHO_REQUEST,0,myChecksum,ID,1)
-  bytesInDouble=struct.calcsize("d")
-  data=(192-bytesInDouble) * "Q"
-  data=struct.pack("d",time.time())+data
+  header = struct.pack( "bbHHh", ICMP_ECHO_REQUEST, 0, myChecksum, ID, 1 )
+  bytesInDouble = struct.calcsize( "d" )
+  data = ( 192 - bytesInDouble ) * "Q"
+  data = struct.pack( "d", time.time() ) + data
+  
   # Calculate the checksum on the data and the dummy header.
-  myChecksum=checksum(header+data)
+  myChecksum = checksum( header + data )
+  
   # Now that we have the right checksum, we put that in. It's just easier
   # to make up a new header than to stuff it into the dummy.
-  header=struct.pack("bbHHh",ICMP_ECHO_REQUEST,0,socket.htons(myChecksum),ID,1)
-  packet=header+data
-  mySocket.sendto(packet,(destAddr,1)) # Don't know about the 1 
-  #return None
-  
-def doOne(destAddr,timeout=10):
+  header = struct.pack( "bbHHh", ICMP_ECHO_REQUEST, 0, 
+                        socket.htons( myChecksum ), ID, 1 )
+                        
+  packet = header + data
+  mySocket.sendto( packet, ( destAddr, 1 ) ) # Don't know about the 1 
+
+def doOne( destAddr, timeout=10 ):
   # Returns either the delay (in seconds) or none on timeout.
-  icmp=socket.getprotobyname("icmp")
-  mySocket=socket.socket(socket.AF_INET,socket.SOCK_RAW,icmp)
-  myID=os.getpid() & 0xFFFF
-  sendOnePing(mySocket,destAddr,myID)
-  delay=receiveOnePing(mySocket,myID,timeout)
+  icmp = socket.getprotobyname( "icmp" )
+  mySocket = socket.socket( socket.AF_INET,socket.SOCK_RAW,icmp )
+  myID = os.getpid() & 0xFFFF
+  sendOnePing( mySocket, destAddr, myID )
+  delay = receiveOnePing( mySocket, myID, timeout )
   mySocket.close()
+  
   return delay
 
 
 def ping( host, timeout=1 ):
-  dest=socket.gethostbyname(host)
-  delay=doOne(dest, timeout)
+  dest = socket.gethostbyname( host )
+  delay = doOne( dest, timeout )
   return delay
-  
+
 # log_exception() adapted from ASPN:
 #    Recipe 65332 by Dirk Holtwick
 #    Recipe 52215 by Bryn Keller
 #    Adapted by Don Welch, 2004
 
 # TODO: Move this to logger module
-
 def log_exception():
     """
     Print the usual traceback information, followed by a listing of all the
     local variables in each frame.
     """
     typ, value, tb = sys.exc_info()
-    
+
     while 1:
         if not tb.tb_next:
             break
         tb = tb.tb_next
-    
+
     stack = []
     f = tb.tb_frame
-    
+
     while f:
         stack.append(f)
         f = f.f_back
-    
+
     stack.reverse()
-    #traceback.print_exc()
-    #log.error( format_traceback() )
-    
-    #typ, value, tb = sys.exc_info()
+
     body = "Traceback (innermost last):\n"
-    list = traceback.format_tb(tb) + traceback.format_exception_only(typ, value)
-    body = body + "%-20s %s" % (''.join( list[:-1] ), list[-1], )
-    
+    lst = traceback.format_tb(tb) + traceback.format_exception_only(typ, value)
+    body = body + "%-20s %s" % (''.join( lst[:-1] ), lst[-1], )
+
     log.error( body )
-    
-    #log.error( "Locals by frame, innermost last" )
-    
-    #for frame in stack:
-        
-    #    log.error( "Frame %s in %s at line %s" % (frame.f_code.co_name,
-    #                                         frame.f_code.co_filename,
-    #                                         frame.f_lineno) )
-    #    for key, value in frame.f_locals.items():
-    #        log.error( "\t%20s = " % key )
-            #We have to be careful not to cause a new error in our error
-            #printer! Calling str() on an unknown object could cause an
-            #error we don't want.
-    #        try:                   
-    #            log.error( value )
-    #        except:
-                #print "<ERROR WHILE PRINTING VALUE>"
-    #            pass
+
+
 
